@@ -16,18 +16,16 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 import logging
-import re
 import sys
 from collections import namedtuple
 from datetime import datetime
 from functools import partial
 from io import TextIOWrapper
-from operator import getitem
 from pathlib import Path
+from unittest.mock import patch
 
 import tomli_w
 from boltons.cacheutils import LRI, cached
-from boltons.strutils import complement_int_list, int_ranges_from_int_list
 from click_extra import (
     STRING,
     Choice,
@@ -39,7 +37,7 @@ from click_extra import (
     option_group,
     pass_context,
 )
-from click_extra.colorize import KO, OK, theme
+from click_extra.colorize import KO, OK, highlight, theme
 from click_extra.platform import os_label
 from click_extra.tabulate import table_format_option
 
@@ -50,10 +48,11 @@ else:
 
 from cloup import Section
 
-from . import __version__, logger, xbar
-from .base import CLI_FORMATS, CLIError, PackageManager
+from . import __version__, bar_plugin, logger
+from .base import CLIError
 from .output import (
     SORTABLE_FIELDS,
+    BarPluginRenderer,
     TabularOutputFormatter,
     print_json,
     print_stats,
@@ -68,7 +67,11 @@ MAINTENANCE = Section("Maintainance commands")
 SNAPSHOTS = Section("Package snapshots commands")
 
 
-XKCD_MANAGER_ORDER = ("pip", "brew", "npm", "dnf", "apt")
+XKCD_MANAGER_ORDER = ("pip", "brew", "npm", "dnf", "apt", "steamcmd")
+"""Sequence of package managers as defined by `XKCD #1654: Universal Install Script <https://xkcd.com/1654/>`_.
+
+See the corresponding `implementation rationale in issue #10 <https://github.com/kdeldycke/meta-package-manager/issues/10>`_.
+"""
 
 
 def add_manager_to_selection(ctx, param, selected):
@@ -96,20 +99,20 @@ def single_manager_selectors():
         )
 
 
-def xbar_plugin_path(ctx, param, value):
-    """Print the location of the xbar plugin.
+def bar_plugin_path(ctx, param, value):
+    """Print the location of the Xbar/SwiftBar plugin.
 
     Replaces the fully-qualified home directory by its shorthand if applicable.
     """
     if value:
-        xbar_path = Path(xbar.__file__).expanduser().resolve()
+        bar_path = Path(bar_plugin.__file__).expanduser().resolve()
         home_dir = Path.home()
-        if xbar_path.is_relative_to(home_dir):
+        if bar_path.is_relative_to(home_dir):
             home_shorthand = Path("~")
-            shorten_xbar_path = home_shorthand / xbar_path.relative_to(home_dir)
-            assert shorten_xbar_path.expanduser().resolve() == xbar_path
-            xbar_path = shorten_xbar_path
-        echo(xbar_path)
+            shorten_bar_path = home_shorthand / bar_path.relative_to(home_dir)
+            assert shorten_bar_path.expanduser().resolve() == bar_path
+            bar_path = shorten_bar_path
+        echo(bar_path)
         ctx.exit()
 
 
@@ -197,13 +200,13 @@ def xbar_plugin_path(ctx, param, value):
     ),
 )
 @option(
-    "--xbar-plugin-path",
+    "--bar-plugin-path",
     is_flag=True,
     default=False,
     expose_value=False,
     is_eager=True,
-    callback=xbar_plugin_path,
-    help="Print location of the mpm xbar plugin.",
+    callback=bar_plugin_path,
+    help="Print location of the mpm Xbar/SwiftBar plugin.",
 )
 @pass_context
 def mpm(
@@ -352,10 +355,17 @@ def installed(ctx):
     installed_data = {}
 
     for manager in ctx.obj.selected_managers:
+
+        try:
+            packages = tuple(manager.installed.values())
+        except NotImplementedError:
+            logger.warning(f"{manager.id} does not implement installed command.")
+            continue
+
         installed_data[manager.id] = {
             "id": manager.id,
             "name": manager.name,
-            "packages": list(manager.installed.values()),
+            "packages": packages,
         }
 
         # Serialize errors at the last minute to gather all we encountered.
@@ -399,17 +409,16 @@ def installed(ctx):
 
 @mpm.command(short_help="List outdated packages.", section=EXPLORE)
 @option(
-    "-c",
-    "--cli-format",
-    type=Choice(sorted(CLI_FORMATS), case_sensitive=False),
-    default="plain",
-    help="Format of CLI fields in JSON output.",
+    "--plugin-output",
+    is_flag=True,
+    default=False,
+    help="Output results for direct consumption by an Xbar/SwiftBar-compatible plugin."
+    " The layout is dynamic depending on environment variables set by both Xbar and "
+    "SwiftBar.",
 )
 @pass_context
-def outdated(ctx, cli_format):
+def outdated(ctx, plugin_output):
     """List available package upgrades and their versions for each manager."""
-    render_cli = partial(PackageManager.render_cli, cli_format=cli_format)
-
     # Build-up a global list of outdated packages per manager.
     outdated_data = {}
 
@@ -422,7 +431,13 @@ def outdated(ctx, cli_format):
             continue
 
         for info in packages:
-            info.update({"upgrade_cli": render_cli(manager.upgrade_cli(info["id"]))})
+            info.update(
+                {
+                    "upgrade_cli": BarPluginRenderer.render_cli(
+                        manager.upgrade_cli(info["id"]), plugin_format=plugin_output
+                    )
+                }
+            )
 
         outdated_data[manager.id] = {
             "id": manager.id,
@@ -436,10 +451,14 @@ def outdated(ctx, cli_format):
             try:
                 upgrade_all_cli = manager.upgrade_all_cli()
             except NotImplementedError:
-                # Fallback on mpm itself which is capable of simulating a full
-                # upgrade.
-                upgrade_all_cli = ("mpm", "--manager", manager.id, "upgrade")
-            outdated_data[manager.id]["upgrade_all_cli"] = render_cli(upgrade_all_cli)
+                # Fallback on mpm itself which is capable of simulating a full upgrade.
+                logger.warning(f"{manager.id} does not implement upgrade_all command.")
+                mpm_exec = bar_plugin.MPMPlugin().mpm_exec
+                upgrade_all_cli = (*mpm_exec, f"--{manager.id}", "upgrade")
+                logger.debug(f"Fallback to direct mpm call: {upgrade_all_cli}")
+            outdated_data[manager.id]["upgrade_all_cli"] = BarPluginRenderer.render_cli(
+                upgrade_all_cli, plugin_format=plugin_output
+            )
 
         # Serialize errors at the last minute to gather all we encountered.
         outdated_data[manager.id]["errors"] = list(
@@ -451,6 +470,11 @@ def outdated(ctx, cli_format):
         print_json(outdated_data)
         return
 
+    # Xbar/SwiftBar-friendly plugin rendering.
+    if plugin_output:
+        BarPluginRenderer().print(outdated_data)
+        return
+
     # Human-friendly content rendering.
     table = []
     for manager_id, outdated_pkg in outdated_data.items():
@@ -514,9 +538,8 @@ def search(ctx, extended, exact, query):
 
     for manager in ctx.obj.selected_managers:
 
-        # Allow managers to not implement search.
         try:
-            results = manager.search(query, extended, exact).values()
+            results = tuple(manager.search(query, extended, exact).values())
         except NotImplementedError:
             logger.warning(f"{manager.id} does not implement search command.")
             continue
@@ -524,7 +547,7 @@ def search(ctx, extended, exact, query):
         matches[manager.id] = {
             "id": manager.id,
             "name": manager.name,
-            "packages": list(results),
+            "packages": results,
         }
 
         # Serialize errors at the last minute to gather all we encountered.
@@ -539,47 +562,22 @@ def search(ctx, extended, exact, query):
 
     # Prepare highlighting helpers.
     query_parts = {query}.union(map(str, TokenizedString(query)))
-
-    @cached(LRI(max_size=1000))
-    def highlight(string):
-        # Ranges of character indices flagged for highlighting.
-        ranges = set()
-
-        for part in query_parts:
-            # Search for occurrences of query parts in original string.
-            occurrences = (
-                match.start() for match in re.finditer(part, string, re.IGNORECASE)
-            )
-            # Flag matching substrings for highlighting.
-            for match_start in occurrences:
-                match_end = match_start + len(part) - 1
-                ranges.add(f"{match_start}-{match_end}")
-
-        # Reduce index ranges, compute complement ranges, transform them to
-        # list of integers.
-        ranges = ",".join(ranges)
-        bold_ranges = int_ranges_from_int_list(ranges)
-        normal_ranges = int_ranges_from_int_list(
-            complement_int_list(ranges, range_end=len(string))
+    highlight_query = cached(LRI(max_size=1000))(
+        partial(
+            highlight,
+            substrings=query_parts,
+            styling_method=theme.search,
+            ignore_case=True,
         )
-
-        # Apply style to range of characters flagged as matching.
-        styled_str = ""
-        for i, j in sorted(bold_ranges + normal_ranges):
-            segment = getitem(string, slice(i, j + 1))
-            if (i, j) in bold_ranges:
-                segment = theme.search(segment)
-            styled_str += segment
-
-        return styled_str
+    )
 
     # Human-friendly content rendering.
     table = []
     for manager_id, matching_pkg in matches.items():
         table += [
             (
-                highlight(info["name"]),
-                highlight(info["id"]),
+                highlight_query(info["name"]),
+                highlight_query(info["id"]),
                 manager_id,
                 info["latest_version"] if info["latest_version"] else "?",
             )
@@ -623,8 +621,9 @@ def install(ctx, package_id):
         try:
             matches = manager.search(extended=False, exact=True, query=package_id)
         except NotImplementedError:
-            logger.warning(
-                f"No way to search for {package_id} with {manager.id}. Try to directly install it."
+            logger.warning(f"{manager.id} does not implement search command.")
+            logger.info(
+                f"{package_id} existence unconfirmed, try to directly install it..."
             )
         else:
             if not matches:
@@ -632,21 +631,18 @@ def install(ctx, package_id):
                 continue
             assert len(matches) == 1
 
-        # Allow install subcommand to fail.
-        default_value = manager.stop_on_error
-        manager.stop_on_error = True
-        try:
-            output = manager.install(package_id)
-        except CLIError:
-            logger.warning(f"Could not install {package_id} with {manager.id}.")
-
-            # Restore default value.
-            manager.stop_on_error = default_value
-
-            continue
-
-        # Restore default value.
-        manager.stop_on_error = default_value
+        # Allow install subcommand to fail to have the oportunity to catch the CLIError exception and print
+        # a comprehensive message.
+        with patch.object(manager, "stop_on_error", True):
+            try:
+                logger.info(f"Install {package_id} package from {manager.id}...")
+                output = manager.install(package_id)
+            except NotImplementedError:
+                logger.warning(f"{manager.id} does not implement install command.")
+                continue
+            except CLIError:
+                logger.warning(f"Could not install {package_id} with {manager.id}.")
+                continue
 
         echo(output)
         return
@@ -661,7 +657,7 @@ def upgrade(ctx):
         try:
             output = manager.upgrade_all()
         except NotImplementedError:
-            logger.warning(f"{manager.id} does not implement upgrade command.")
+            logger.warning(f"{manager.id} does not implement upgrade_all command.")
             continue
 
         if output:
@@ -673,7 +669,11 @@ def upgrade(ctx):
 def sync(ctx):
     """Sync local package metadata and info from external sources."""
     for manager in ctx.obj.selected_managers:
-        manager.sync()
+        logger.info(f"Sync {manager.id} package info...")
+        try:
+            manager.sync()
+        except NotImplementedError:
+            logger.warning(f"{manager.id} does not implement sync command.")
 
 
 @mpm.command(short_help="Cleanup local data.", section=MAINTENANCE)
@@ -681,7 +681,11 @@ def sync(ctx):
 def cleanup(ctx):
     """Cleanup local data and temporary artifacts."""
     for manager in ctx.obj.selected_managers:
-        manager.cleanup()
+        logger.info(f"Cleanup {manager.id}...")
+        try:
+            manager.cleanup()
+        except NotImplementedError:
+            logger.warning(f"{manager.id} does not implement cleanup command.")
 
 
 @mpm.command(short_help="Save installed packages to a TOML file.", section=SNAPSHOTS)
@@ -718,16 +722,21 @@ def backup(ctx, toml_output):
     # Create one section for each package manager.
     for manager in ctx.obj.selected_managers:
         logger.info(f"Dumping packages from {manager.id}...")
-        installed_packages = manager.installed.values()
+
+        try:
+            packages = manager.installed.values()
+        except NotImplementedError:
+            logger.warning(f"{manager.id} does not implement installed command.")
+            continue
 
         # Prepare data for stats.
         installed_data[manager.id] = {
             "id": manager.id,
-            "packages": installed_packages,
+            "packages": packages,
         }
 
         pkg_data = dict(
-            sorted((p["id"], str(p["installed_version"])) for p in installed_packages)
+            sorted((p["id"], str(p["installed_version"])) for p in packages)
         )
 
         if pkg_data:
@@ -773,5 +782,8 @@ def restore(ctx, toml_files):
                 continue
             logger.info(f"Restore {manager.id} packages...")
             for package_id, version in doc[manager.id].items():
+                # Let the command fail if the package manager doesn't implement the
+                # install operation.
+                logger.info(f"Install {package_id} package from {manager.id}...")
                 output = manager.install(package_id)
                 echo(output)
