@@ -30,13 +30,15 @@ class APT(PackageManager):
     Documentation:
     - https://wiki.debian.org/AptCLI
     - http://manpages.ubuntu.com/manpages/xenial/man8/apt.8.html
+
+    See other command equivalences at: https://wiki.archlinux.org/title/Pacman/Rosetta
     """
 
     platforms = frozenset({LINUX})
 
     requirement = "1.0.0"
 
-    post_args = ("--yes", "--quiet")
+    post_args = ("--quiet",)
 
     version_regex = r"apt\s+(?P<version>\S+)"
     """
@@ -48,11 +50,11 @@ class APT(PackageManager):
 
     @property
     def installed(self):
-        """Fetch installed packages from ``apt list`` output.
+        """Fetch installed packages.
 
         .. code-block:: shell-session
 
-            ► apt list --installed --yes --quiet
+            ► apt list --installed --quiet
             Listing...
             adduser/xenial,now 3.113+nmu3ubuntu4 all [installed]
             base-files/xenial-updates,now 9.4ubuntu4.3 amd64 [installed]
@@ -98,11 +100,11 @@ class APT(PackageManager):
 
     @property
     def outdated(self):
-        """Fetch outdated packages from ``apt list`` output.
+        """Fetch outdated packages.
 
         .. code-block:: shell-session
 
-            ► apt list --upgradable --yes --quiet
+            ► apt list --upgradable --quiet
             Listing...
             apt/xenial-updates 1.2.19 amd64 [upgradable from: 1.2.15ubuntu0.2]
             nano/xenial-updates 2.5.3-2ubuntu2 amd64 [upgradable from: 2.5.3-2]
@@ -126,11 +128,11 @@ class APT(PackageManager):
         return outdated
 
     def search(self, query, extended, exact):
-        """Fetch matching packages from ``apt search`` output.
+        """Fetch matching packages.
 
         .. code-block:: shell-session
 
-            ► apt search abc --names-only --yes --quiet
+            ► apt search abc --names-only --quiet
             Sorting...
             Full Text Search...
             abcde/xenial 2.7.1-1 all
@@ -150,7 +152,7 @@ class APT(PackageManager):
 
         .. code-block:: shell-session
 
-            ► apt search ^sed$ --names-only --yes --quiet
+            ► apt search ^sed$ --names-only --quiet
             Sorting...
             Full Text Search...
             sed/xenial 2.1.9-3 all
@@ -158,7 +160,7 @@ class APT(PackageManager):
 
         .. code-block:: shell-session
 
-            ► apt search abc --full --yes --quiet
+            ► apt search abc --full --quiet
             Sorting...
             Full Text Search...
             abcde/xenial 2.7.1-1 all
@@ -220,25 +222,25 @@ class APT(PackageManager):
 
             ► sudo apt install git --yes --quiet
         """
-        super().install(package_id)
-        return self.run_cli("install", package_id, override_pre_cmds=("sudo",))
+        return self.run_cli("install", package_id, "--yes", sudo=True)
 
     def upgrade_cli(self, package_id=None):
-        """Generates the upgrade CLI.
+        """Generates the CLI to upgrade all packages (default) or only the one provided
+        as parameter.
 
-        .. code-block:: shell-session.
-
-            ► sudo apt install --only-upgrade git --yes --quiet
-
-        .. code-block:: shell-session.
+        .. code-block:: shell-session
 
             ► sudo apt upgrade --yes --quiet
+
+        .. code-block:: shell-session
+
+            ► sudo apt install --only-upgrade git --yes --quiet
         """
+        params = ("upgrade",)
         if package_id:
-            return self.build_cli(
-                "install", "--only-upgrade", package_id, override_pre_cmds=("sudo",)
-            )
-        return self.build_cli("upgrade", override_pre_cmds=("sudo",))
+            params = ("install", "--only-upgrade", package_id)
+
+        return self.build_cli(*params, "--yes", sudo=True)
 
     def sync(self):
         """Sync package metadata.
@@ -255,20 +257,18 @@ class APT(PackageManager):
             Building dependency tree...
             Reading state information...
         """
-        super().sync()
-        self.run_cli("update", override_pre_cmds=("sudo",))
+        self.run_cli("update", "--yes", sudo=True)
 
     def cleanup(self):
-        """Runs:
+        """Removes things we don't need anymore.
 
         .. code-block:: shell-session
 
             ► sudo apt autoremove --yes --quiet
             ► sudo apt clean --yes --quiet
         """
-        super().cleanup()
         for command in ("autoremove", "clean"):
-            self.run_cli(command, override_pre_cmds=("sudo",))
+            self.run_cli(command, "--yes", sudo=True)
 
 
 class APT_Mint(APT):
@@ -291,9 +291,11 @@ class APT_Mint(APT):
     """
 
     def search(self, query, extended, exact):
-        """.. code-block:: shell-session.
+        """Fetch matching packages.
 
-            ► /usr/local/bin/apt search sed --yes --quiet
+        .. code-block:: shell-session
+
+            ► /usr/local/bin/apt search sed --quiet
             v   librust-slog-2.5+erased-serde-dev  -
             p   python3-blessed                    - Practical wrapper
             i   sed                                - GNU stream editor
@@ -301,7 +303,7 @@ class APT_Mint(APT):
 
         .. code-block:: shell-session
 
-            ► /usr/local/bin/apt search ^sed$ --yes --quiet
+            ► /usr/local/bin/apt search ^sed$ --quiet
             i   sed              - GNU stream editor
             p   sed:i386         - GNU stream editor
         """
