@@ -24,16 +24,17 @@ from ..version import parse_version
 
 
 class DNF(PackageManager):
-
     """
     Documentation: https://dnf.readthedocs.io/en/latest/command_ref.html
+
+    See other command equivalences at: https://wiki.archlinux.org/title/Pacman/Rosetta
     """
 
     platforms = frozenset({LINUX})
 
     requirement = "4.0.0"
 
-    cli_names = ("dnf", "yum")
+    cli_names = ("dnf",)
 
     """
     .. code-block:: shell-session
@@ -48,12 +49,16 @@ class DNF(PackageManager):
 
     @property
     def installed(self):
-        """.. code-block:: shell-session.
+        """Fetch installed packages.
 
-        ► dnf --color=never list --installed Installed Packages acl.x86_64
-        2.2.53-1.el8                          @anaconda audit.x86_64
-        3.0-0.10.20180831git0047a6c.el8       @anaconda audit-libs.x86_64
-        3.0-0.10.20180831git0047a6c.el8       @anaconda (...)
+        .. code-block:: shell-session
+
+            ► dnf --color=never list --installed
+            Installed Packages
+            acl.x86_64         2.2.53-1.el8                         @anaconda
+            audit.x86_64       3.0-0.10.20180831git0047a6c.el8      @anaconda
+            audit-libs.x86_64  3.0-0.10.20180831git0047a6c.el8      @anaconda
+            (...)
         """
         installed = {}
 
@@ -73,12 +78,17 @@ class DNF(PackageManager):
 
     @property
     def outdated(self):
-        """.. code-block:: shell-session.
+        """Fetch outdated packages.
 
-        ► dnf --color=never list --upgrades Last metadata expiration check: 0:22:12 ago
-        on Sun 03 Apr 2022. Available Upgrades acl.x86_64               2.2.53-1.el8
-        updates audit.x86_64             3.0-0.10.20180831git0047a6c.el8       updates
-        audit-libs.x86_64        3.0-0.10.20180831git0047a6c.el8       updates (...)
+        .. code-block:: shell-session
+
+            ► dnf --color=never list --upgrades
+            Last metadata expiration check: 0:22:12 ago on Sun 03 Apr 2022.
+            Available Upgrades
+            acl.x86_64               2.2.53-1.el8                        updates
+            audit.x86_64             3.0-0.10.20180831git0047a6c.el8     updates
+            audit-libs.x86_64        3.0-0.10.20180831git0047a6c.el8     updates
+            (...)
         """
         outdated = {}
 
@@ -97,18 +107,20 @@ class DNF(PackageManager):
         return outdated
 
     def search(self, query, extended, exact):
-        """.. code-block:: shell-session.
+        """Fetch matching packages.
 
-        ► dnf --color=never search usd
-        Last metadata expiration check: 0:06:37 ago on Sun 03 Apr 2022.
-        =================== Name Exactly Matched: usd =====================
-        usd.aarch64 : 3D VFX pipeline interchange file format
-        =================== Name & Summary Matched: usd ===================
-        python3-usd.aarch64 : Development files for USD
-        usd-devel.aarch64 : Development files for USD
-        ======================= Name Matched: usd =========================
-        lvm2-dbusd.noarch : LVM2 D-Bus daemon
-        usd-libs.aarch64 : Universal Scene Description library
+        .. code-block:: shell-session
+
+            ► dnf --color=never search usd
+            Last metadata expiration check: 0:06:37 ago on Sun 03 Apr 2022.
+            =================== Name Exactly Matched: usd =====================
+            usd.aarch64 : 3D VFX pipeline interchange file format
+            =================== Name & Summary Matched: usd ===================
+            python3-usd.aarch64 : Development files for USD
+            usd-devel.aarch64 : Development files for USD
+            ======================= Name Matched: usd =========================
+            lvm2-dbusd.noarch : LVM2 D-Bus daemon
+            usd-libs.aarch64 : Universal Scene Description library
         """
         matches = {}
 
@@ -147,39 +159,50 @@ class DNF(PackageManager):
         return matches
 
     def install(self, package_id):
-        """.. code-block:: shell-session.
+        """Install one package.
 
-        ► sudo dnf --color=never --assumeyes install pip
+        .. code-block:: shell-session
+
+            ► sudo dnf --color=never --assumeyes install pip
         """
-        super().install(package_id)
-        return self.run_cli(
-            "--assumeyes", "install", package_id, override_pre_cmds=("sudo",)
-        )
+        return self.run_cli("--assumeyes", "install", package_id, sudo=True)
 
     def upgrade_cli(self, package_id=None):
-        """.. code-block:: shell-session.
-
-            ► sudo dnf --color=never --assumeyes upgrade pip
+        """Generates the CLI to upgrade all packages (default) or only the one provided
+        as parameter.
 
         .. code-block:: shell-session
 
             ► sudo dnf --color=never --assumeyes upgrade
+
+        .. code-block:: shell-session
+
+            ► sudo dnf --color=never --assumeyes upgrade pip
         """
-        return self.build_cli("upgrade", package_id)
+        return self.build_cli("upgrade", package_id, sudo=True)
 
     def sync(self):
-        """.. code-block:: shell-session.
+        """Sync package metadata.
 
-        ► dnf --color=never check-update
+        .. code-block:: shell-session
+
+            ► dnf --color=never check-update
         """
-        super().sync()
         self.run_cli("check-update")
 
     def cleanup(self):
-        """.. code-block:: shell-session.
+        """Removes things we don't need anymore.
 
-        ► sudo dnf --color=never --assumeyes autoremove ► dnf --color=never clean all
+        .. code-block:: shell-session
+
+            ► sudo dnf --color=never --assumeyes autoremove
+            ► dnf --color=never clean all
         """
-        super().cleanup()
-        self.run_cli("--assumeyes", "autoremove", override_pre_cmds=("sudo",))
+        self.run_cli("--assumeyes", "autoremove", sudo=True)
         self.run_cli("clean", "all")
+
+
+class YUM(DNF):
+    """yum is dnf is yum."""
+
+    cli_names = ("yum",)
