@@ -273,11 +273,10 @@ class Pip(PackageManager):
             Installing collected packages: python-dateutil, arrow
             Successfully installed arrow-1.1.1 python-dateutil-2.8.2
         """
-        super().install(package_id)
         return self.run_cli("install", package_id)
 
     def upgrade_cli(self, package_id):
-        """Build-up package upgrade CLI.
+        """Generates the CLI to upgrade the package provided as parameter.
 
         .. code-block:: shell-session
 
@@ -291,15 +290,12 @@ class Pip(PackageManager):
                   Successfully uninstalled six-1.14.0
             Successfully installed six-1.15.0
         """
-        return self.build_cli(
-            "install",
-            "--user",
-            "--upgrade",
-            package_id,
-        )
+        return self.build_cli("install", "--user", "--upgrade", package_id)
 
     def upgrade_all_cli(self):
-        """Pip lacks support of a proper full upgrade command. Raising an error let the
+        """Generates the CLI to upgrade all packages.
+
+        Pip lacks support of a proper full upgrade command. Raising an error let the
         parent class upgrade packages one by one.
 
         See: https://github.com/pypa/pip/issues/59
