@@ -43,11 +43,10 @@ class Snap(PackageManager):
 
     @property
     def installed(self):
-        """Fetch installed packages from ``snap list`` output.
-
-        Raw CLI output samples:
+        """Fetch installed packages.
 
         .. code-block:: shell-session
+
             ► snap list --color=never
             Name    Version    Rev   Aufzeichnung   Herausgeber     Hinweise
             core    16-2.44.1  8935  latest/stable  canonical✓      core
@@ -71,9 +70,7 @@ class Snap(PackageManager):
 
     @property
     def outdated(self):
-        """Fetch outdated packages from ``snap refresh --list`` output.
-
-        Raw CLI output samples:
+        """Fetch outdated packages.
 
         .. code-block:: shell-session
 
@@ -101,9 +98,10 @@ class Snap(PackageManager):
         return outdated
 
     def search(self, query, extended, exact):
-        """Fetch matching packages from ``snap find`` output.
+        """Fetch matching packages.
 
         .. code-block:: shell-session
+
             ► snap find doc --color=never
             Name       Version      Herausgeber  Hinweise  Zusammenfassung
             journey    2.14.3       2appstudio   -         Your private diary.
@@ -148,17 +146,20 @@ class Snap(PackageManager):
 
             ► snap install standard-notes --color=never
         """
-        super().install(package_id)
         return self.run_cli("install", package_id)
 
     def upgrade_cli(self, package_id=None):
-        """Snap has an auto-update function, but snaps can be updated manually.
+        """Generates the CLI to upgrade all packages (default) or only the one provided
+        as parameter.
+
+        Snap has an auto-update function, but snaps can be updated manually.
+
+        .. code-block:: shell-session
+
+            ► snap refresh --color=never
 
         .. code-block:: shell-session
 
             ► snap refresh standard-notes --color=never
         """
-        return self.build_cli(
-            "refresh",
-            package_id,
-        )
+        return self.build_cli("refresh", package_id)
