@@ -18,12 +18,14 @@
 import json
 import re
 import subprocess
+from shutil import which
 
 import pytest
 from boltons.strutils import strip_ansi
 from click_extra.tabulate import TabularOutputFormatter
 
 from .. import __version__
+from ..bar_plugin import MPMPlugin
 from ..pool import pool
 
 """ Common tests for all CLI basic features and templates for subcommands. """
@@ -58,8 +60,12 @@ class TestBaseCLI:
     """
 
     def test_executable_module(self):
+        # Locate Python executable.
+        py_path = MPMPlugin.locate_bin("python", "python3")
+        assert py_path
+
         process = subprocess.run(
-            ("python", "-m", "meta_package_manager", "--version"),
+            (py_path, "-m", "meta_package_manager", "--version"),
             capture_output=True,
             encoding="utf-8",
         )
@@ -135,7 +141,7 @@ class CLISubCommandTests:
 
         This explain the use of ``set()`` everywhere.
 
-        .. todo:
+        .. todo::
 
             Parametrize/fixturize signals to pin point output depending on
             subcommand.
@@ -161,7 +167,7 @@ class CLISubCommandTests:
                 bool(
                     re.search(
                         rf"warning: {mid} does not implement "
-                        r"(search|outdated|upgrade|sync|cleanup|install|upgrade_all) "
+                        r"(installed|outdated|search|install|upgrade|upgrade_all|sync|cleanup) "
                         "command.",
                         stderr,
                     )
@@ -175,18 +181,6 @@ class CLISubCommandTests:
                         stdout,
                     )
                 ),
-                # Sync command.
-                f"Sync {mid} package info..." in stderr,
-                # Upgrade command.
-                f"Updating all outdated packages from {mid}..." in stderr,
-                # Cleanup command.
-                f"Cleanup {mid}..." in stderr,
-                # Log message for backup command.
-                f"Dumping packages from {mid}..." in stderr,
-                # Restoring message.
-                f"Restore {mid} packages..." in stderr,
-                # Warning message for restore command.
-                f"warning: No [{mid}] section found." in stderr,
                 # Install message.
                 bool(
                     re.search(
@@ -200,6 +194,18 @@ class CLISubCommandTests:
                         stderr,
                     )
                 ),
+                # Upgrade command.
+                f"Updating all outdated packages from {mid}..." in stderr,
+                # Sync command.
+                f"Sync {mid} package info..." in stderr,
+                # Cleanup command.
+                f"Cleanup {mid}..." in stderr,
+                # Log message for backup command.
+                f"Dumping packages from {mid}..." in stderr,
+                # Warning message for restore command.
+                f"warning: No [{mid}] section found." in stderr,
+                # Restoring message.
+                f"Restore {mid} packages..." in stderr,
             )
 
             if True in signals:
