@@ -90,6 +90,12 @@ class Token:
     def __str__(self):
         return self.string
 
+    def __len__(self):
+        return len(self.string)
+
+    def __format__(self, format_spec):
+        return self.string.__format__(format_spec)
+
     def __int__(self):
         return self.integer
 
@@ -98,14 +104,13 @@ class Token:
         """Does the Token got a pure integer representation?"""
         return self.integer is not None
 
-    """ In the best case, try to comparison Token to integers.
+    """ Compare the current Token instance to the other as intergers if both can be losslessly interpreted as pure integers.
 
-    If one or the two is an integer but not the other, we convert all to
-    string to allow comparison.
+    If one at least is not an integer, we convert all of them to string to allow comparison.
     """
 
     def _match_type(self, other):
-        """Returns the safe type with which we can compare two values."""
+        """Returns the safe type with which we can compare the two values."""
         if self.isint:
             if isinstance(other, int):
                 return int
@@ -174,6 +179,12 @@ class TokenizedString:
     def __str__(self):
         return self.string
 
+    def __len__(self):
+        return len(self.string)
+
+    def __format__(self, format_spec):
+        return self.string.__format__(format_spec)
+
     def pretty_print(self):
         return self.separator.join(map(str, self.tokens))
 
@@ -185,6 +196,8 @@ class TokenizedString:
         strings and integers. That way we get natural, user-friendly sorting of
         version numbers. That we can get with simple Python, see:
 
+        .. code-block:: python
+
             >>> '2019.0.1' > '9.3'
             False
             >>> ('2019', '0', '1') > ('9', '3')
@@ -229,5 +242,5 @@ class TokenizedString:
             return tuple(self) <= tuple(other)
 
 
-""" Utility method tweaking TokenizedString for dot-based serialization. """
 parse_version = partial(TokenizedString, separator=".")
+""" Utility method tweaking TokenizedString for dot-based serialization. """
